@@ -8,7 +8,7 @@ from flask import Request, jsonify, abort
 from . import util
 
 
-MEDIATOR_URL = os.environ["MEDIATOR_URL"]
+SERVICE_CATALOG = os.environ["SERVICE_CATALOG"]
 
 
 def _get_auth_token(audience):
@@ -23,8 +23,13 @@ def _get_auth_token(audience):
 
 
 def call(service_name, service_path=None, **kwargs):
-    auth = {"Authorization": "Bearer " + _get_auth_token(MEDIATOR_URL)}
-    r = requests.post(MEDIATOR_URL, headers=auth, json=kwargs)
+    url = SERVICE_CATALOG.get(service_name)
+    if not url:
+        raise Exception(f"Service '{service_name}' not found in catalog.")
+    if service_path:
+        url += f"/{service_path}"
+    auth = {"Authorization": "Bearer " + _get_auth_token(url)}
+    r = requests.post(url, headers=auth, json=kwargs)
     if r.status_code >= 500:
         r.raise_for_status()
     return r
@@ -43,6 +48,12 @@ def auth(permission):
     def wrap(func):
         def wrapped_func(request: Request):
             try:
+                if not "asset" in request.json:
+                    resp = jsonify(
+                        message="Missing required 'asset' parameter in authorized request."
+                    )
+                    resp.status_code = 400
+                    abort(resp)
                 r = call(
                     "db",
                     "authorize",
@@ -55,7 +66,7 @@ def auth(permission):
                     resp = jsonify(message="Access denied.")
                     resp.status_code = 403
                     abort(resp)
-            except HTTPError as e:
+            except Exception as e:
                 logging.exception(e)
                 resp = jsonify(message="An unexpected error occurred in authorization.")
                 resp.status_code = 500
